@@ -76,7 +76,8 @@ func NewCmdLogin(f *cmdutils.Factory) *cobra.Command {
 
 			# Non-interactive setup reading token from a file
 			$ glab auth login --hostname gitlab.example.org --api-host gitlab.example.org:3443 --api-protocol https --git-protocol ssh  --stdin < myaccesstoken.txt
-			# non-interactive job token setup
+
+			# Non-interactive job token setup
 			$ glab auth login --hostname gitlab.example.org --job-token $CI_JOB_TOKEN
 		`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
