@@ -9,7 +9,7 @@ import (
 	"gitlab.com/gitlab-org/cli/api"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/pkg/git"
 )
@@ -17,10 +17,11 @@ import (
 func NewCmdGenerate(f *cmdutils.Factory) *cobra.Command {
 	changelogGenerateCmd := &cobra.Command{
 		Use:   "generate [flags]",
-		Short: `Generate a changelog for the repository/project`,
+		Short: `Generate a changelog for the repository or project.`,
 		Long:  ``,
 		Example: heredoc.Doc(`
-			glab changelog generate
+			# Generate a changelog
+			$ glab changelog generate
 		`),
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -46,12 +47,12 @@ func NewCmdGenerate(f *cmdutils.Factory) *cobra.Command {
 				}
 
 				if len(tags) == 0 {
-					return errors.New("no tags found. Either fetch tags or pass a version with --version instead")
+					return errors.New("no tags found. Either fetch tags, or pass a version with --version instead.")
 				}
 
 				version, err := git.DescribeByTags()
 				if err != nil {
-					return fmt.Errorf("failed to determine version from git describe: %w..", err)
+					return fmt.Errorf("failed to determine version from `git describe`: %w..", err)
 				}
 				opts.Version = gitlab.Ptr(version)
 			}
@@ -105,12 +106,12 @@ func NewCmdGenerate(f *cmdutils.Factory) *cobra.Command {
 
 	// The options mimic the ones from the REST API.
 	// https://docs.gitlab.com/ee/api/repositories.html#generate-changelog-data
-	changelogGenerateCmd.Flags().StringP("version", "v", "", "The version to generate the changelog for. The format must follow semantic versioning. Defaults to the version of the local checkout (like using git describe).")
-	changelogGenerateCmd.Flags().StringP("config-file", "", "", "The path of changelog configuration file in the project's Git repository. Defaults to .gitlab/changelog_config.yml.")
-	changelogGenerateCmd.Flags().StringP("date", "", "", "The date and time of the release. Uses ISO 8601 (2016-03-11T03:45:40Z) format. Defaults to the current time.")
-	changelogGenerateCmd.Flags().StringP("from", "", "", "The start of the range of commits (as a SHA) to use for generating the changelog. This commit itself isn't included in the list.")
-	changelogGenerateCmd.Flags().StringP("to", "", "", "The end of the range of commits (as a SHA) to use for the changelog. This commit is included in the list. Defaults to the HEAD of the default project branch.")
-	changelogGenerateCmd.Flags().StringP("trailer", "", "", "The Git trailer to use for including commits. Defaults to Changelog.")
+	changelogGenerateCmd.Flags().StringP("version", "v", "", "Version to generate the changelog for. Must follow semantic versioning. Defaults to the version of the local checkout, like using 'git describe'.")
+	changelogGenerateCmd.Flags().StringP("config-file", "", "", "Path of the changelog configuration file in the project's Git repository. Defaults to '.gitlab/changelog_config.yml'.")
+	changelogGenerateCmd.Flags().StringP("date", "", "", "Date and time of the release. Uses ISO 8601 (`2016-03-11T03:45:40Z`) format. Defaults to the current time.")
+	changelogGenerateCmd.Flags().StringP("from", "", "", "Start of the range of commits (as a SHA) to use when generating the changelog. This commit itself isn't included in the list.")
+	changelogGenerateCmd.Flags().StringP("to", "", "", "End of the range of commits (as a SHA) to use when generating the changelog. This commit is included in the list. Defaults to the HEAD of the project's default branch.")
+	changelogGenerateCmd.Flags().StringP("trailer", "", "", "The Git trailer to use for including commits. Defaults to 'Changelog'.")
 
 	return changelogGenerateCmd
 }
