@@ -20,9 +20,9 @@ func NewCmdList(f *cmdutils.Factory) *cobra.Command {
 		Use:   "list [flags]",
 		Short: `Get the list of CI/CD pipelines.`,
 		Example: heredoc.Doc(`
-	glab ci list
-	glab ci list --status=failed
-	`),
+			$ glab ci list
+			$ glab ci list --status=failed
+		`),
 		Long: ``,
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -39,14 +39,16 @@ func NewCmdList(f *cmdutils.Factory) *cobra.Command {
 				return err
 			}
 
-			l := &gitlab.ListProjectPipelinesOptions{}
+			l := &gitlab.ListProjectPipelinesOptions{
+				ListOptions: gitlab.ListOptions{
+					Page:    1,
+					PerPage: 30,
+				},
+			}
 
 			format, _ := cmd.Flags().GetString("output")
 			jsonOut := format == "json"
 
-			l.Page = 1
-			l.PerPage = 30
-
 			if m, _ := cmd.Flags().GetString("status"); m != "" {
 				l.Status = gitlab.Ptr(gitlab.BuildStateValue(m))
 				titleQualifier = m
@@ -85,14 +87,14 @@ func NewCmdList(f *cmdutils.Factory) *cobra.Command {
 				l.Username = gitlab.Ptr(m)
 			}
 			if m, _ := cmd.Flags().GetString("updated-after"); m != "" {
-				updatedAfterTime, err := time.Parse("2006-01-02 15:04:05Z", m)
+				updatedAfterTime, err := time.Parse("2006-01-02T15:04:05Z", m)
 				if err != nil {
 					return err
 				}
 				l.UpdatedAfter = gitlab.Ptr(updatedAfterTime)
 			}
 			if m, _ := cmd.Flags().GetString("updated-before"); m != "" {
-				updatedBeforeTime, err := time.Parse("2006-01-02 15:04:05Z", m)
+				updatedBeforeTime, err := time.Parse("2006-01-02T15:04:05Z", m)
 				if err != nil {
 					return err
 				}
@@ -118,7 +120,7 @@ func NewCmdList(f *cmdutils.Factory) *cobra.Command {
 			return nil
 		},
 	}
-	pipelineListCmd.Flags().StringP("status", "s", "", "Get pipeline with this status. Options: running, pending, success, failed, canceled, skipped, created, manual, waiting_for_resource, preparing, scheduled}")
+	pipelineListCmd.Flags().StringP("status", "s", "", "Get pipeline with this status. Options: running, pending, success, failed, canceled, skipped, created, manual, waiting_for_resource, preparing, scheduled")
 	pipelineListCmd.Flags().StringP("orderBy", "o", "id", "Order pipelines by this field. Options: id, status, ref, updated_at, user_id.")
 	pipelineListCmd.Flags().StringP("sort", "", "desc", "Sort pipelines. Options: asc, desc.")
 	pipelineListCmd.Flags().IntP("page", "p", 1, "Page number.")
