@@ -10,8 +10,9 @@ import (
 	glab_api "gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 //go:generate go run go.uber.org/mock/mockgen@v0.4.0 -typed -destination=./mocks_for_test.go -package=bootstrap gitlab.com/gitlab-org/cli/commands/cluster/agent/bootstrap API,FluxWrapper,KubectlWrapper,Cmd
@@ -41,7 +42,7 @@ type KubectlWrapper interface {
 type (
 	APIFactory            func(*gitlab.Client, any) API
 	KubectlWrapperFactory func(Cmd, string, string, string) KubectlWrapper
-	FluxWrapperFactory    func(Cmd, string, string, string, string, string, string, string, string, string, string, string, string) FluxWrapper
+	FluxWrapperFactory    func(Cmd, string, string, string, string, string, string, string, string, string, []string, []string, string, string, string) FluxWrapper
 	CmdFactory            func(io.Writer, io.Writer, []string) Cmd
 )
 
@@ -75,35 +76,44 @@ It requires the kubectl and flux commands to be accessible via $PATH.
 This command consists of multiple idempotent steps:
 
 1. Register the agent with the project.
-1. Configure the agent.
-1. Configure an environment with dashboard for the agent.
-1. Create a token for the agent.
+2. Configure the agent.
+3. Configure an environment with dashboard for the agent.
+4. Create a token for the agent.
    - If the agent has reached the maximum amount of tokens,
      the one that has not been used the longest is revoked
      and a new one is created.
    - If the agent has not reached the maximum amount of tokens,
      a new one is created.
-1. Push the Kubernetes Secret that contains the token to the cluster.
-1. Create Flux HelmRepository and HelmRelease resource.
-1. Commit and Push the created Flux Helm resources to the manifest path.
-1. Trigger Flux reconciliation of GitLab Agent HelmRelease.
+5. Push the Kubernetes Secret that contains the token to the cluster.
+6. Create Flux HelmRepository and HelmRelease resource.
+7. Commit and Push the created Flux Helm resources to the manifest path.
+8. Trigger Flux reconciliation of GitLab Agent HelmRelease.
 `,
-		Example: `
-# Bootstrap "my-agent" to root of Git project in CWD and trigger reconciliation
-glab cluster agent bootstrap my-agent
+		Example: heredoc.Doc(`
+			# Bootstrap "my-agent" to root of Git project in CWD and trigger reconciliation
+			$ glab cluster agent bootstrap my-agent
 
-# Bootstrap "my-agent" to "manifests/" of Git project in CWD and trigger reconciliation
-glab cluster agent bootstrap my-agent --manifest-path manifests/
+			# Bootstrap "my-agent" to "manifests/" of Git project in CWD and trigger reconciliation
+			# This is especially useful when "flux bootstrap gitlab --path manifests/" was used.
+			# Make sure that the "--path" from the "flux bootstrap gitlab" command matches
+			# the "--manifest-path" of the "glab cluster agent bootstrap" command.
+			$ glab cluster agent bootstrap my-agent --manifest-path manifests/
 
-# Bootstrap "my-agent" to "manifests/" of Git project in CWD and do not manually trigger a reconilication
-glab cluster agent bootstrap my-agent --manifest-path manifests/ --no-reconcile
+			# Bootstrap "my-agent" to "manifests/" of Git project in CWD and do not manually trigger a reconilication
+			$ glab cluster agent bootstrap my-agent --manifest-path manifests/ --no-reconcile
 
-# Bootstrap "my-agent" without configuring an environment
-glab cluster agent bootstrap my-agent --create-environment=false
+			# Bootstrap "my-agent" without configuring an environment
+			$ glab cluster agent bootstrap my-agent --create-environment=false
 
-# Bootstrap "my-agent" and configure an environment with custom name and Kubernetes namespace
-glab cluster agent bootstrap my-agent --environment-name production --environment-namespace default
-`,
+			# Bootstrap "my-agent" and configure an environment with custom name and Kubernetes namespace
+			$ glab cluster agent bootstrap my-agent --environment-name production --environment-namespace default
+
+			# Bootstrap "my-agent" and pass additional GitLab Helm Chart values from a local file
+			$ glab cluster agent bootstrap my-agent --helm-release-values values.yaml
+
+			# Bootstrap "my-agent" and pass additional GitLab Helm Chart values from a Kubernetes ConfigMap
+			$ glab cluster agent bootstrap my-agent --helm-release-values-from ConfigMap/agent-config
+		`),
 		Aliases: []string{"bs"},
 		Args:    cobra.ExactArgs(1),
 		PreRunE: func(cmd *cobra.Command, args []string) error {
@@ -173,6 +183,14 @@ glab cluster agent bootstrap my-agent --environment-name production --environmen
 			if err != nil {
 				return err
 			}
+			helmReleaseValues, err := cmd.Flags().GetStringSlice("helm-release-values")
+			if err != nil {
+				return err
+			}
+			helmReleaseValuesFrom, err := cmd.Flags().GetStringSlice("helm-release-values-from")
+			if err != nil {
+				return err
+			}
 
 			gitlabAgentTokenSecretName, err := cmd.Flags().GetString("gitlab-agent-token-secret-name")
 			if err != nil {
@@ -245,6 +263,7 @@ glab cluster agent bootstrap my-agent --environment-name production --environmen
 					c, fluxBinaryName, manifestPath,
 					helmRepositoryName, helmRepositoryNamespace, helmRepositoryFilepath,
 					helmReleaseName, helmReleaseNamespace, helmReleaseFilepath, helmReleaseTargetNamespace,
+					helmReleaseValues, helmReleaseValuesFrom,
 					fluxSourceType, fluxSourceNamespace, fluxSourceName,
 				),
 				noReconcile:    noReconcile,
@@ -265,6 +284,8 @@ glab cluster agent bootstrap my-agent --environment-name production --environmen
 	agentBootstrapCmd.Flags().String("helm-release-namespace", "flux-system", "Namespace of the Flux HelmRelease manifest.")
 	agentBootstrapCmd.Flags().String("helm-release-filepath", "gitlab-agent-helm-release.yaml", "Filepath within the GitLab Agent project to commit the Flux HelmRelease to.")
 	agentBootstrapCmd.Flags().String("helm-release-target-namespace", "gitlab-agent", "Namespace of the GitLab Agent deployment.")
+	agentBootstrapCmd.Flags().StringSlice("helm-release-values", nil, "Local path to values.yaml files")
+	agentBootstrapCmd.Flags().StringSlice("helm-release-values-from", nil, "Kubernetes object reference that contains the values.yaml data key in the format '<kind>/<name>', where kind must be one of: (Secret,ConfigMap)")
 
 	agentBootstrapCmd.Flags().String("gitlab-agent-token-secret-name", "gitlab-agent-token", "Name of the Secret where the token for the GitLab Agent is stored. The helm-release-target-namespace is implied for the namespace of the Secret.")
 
@@ -378,7 +399,7 @@ func (c *bootstrapCmd) run() error {
 		fmt.Fprintln(c.stderr, "Output from flux command:")
 		err = c.fluxReconcile()
 		if err != nil {
-			return reconcileErr
+			return fmt.Errorf("%w:\n%w", reconcileErr, err)
 		}
 	} else {
 		fmt.Fprintf(c.stderr, "[SKIPPED]\n")
