@@ -322,7 +322,7 @@ func StubFactory(repo string) *cmdutils.Factory {
 	cmdutils.CachedConfig = config.NewBlankConfig()
 
 	CachedTestFactory = cmdutils.NewFactory()
-	cmdutils.HTTPClientFactory(CachedTestFactory)
+	CachedTestFactory.HttpClient = cmdutils.HTTPClientFunc
 	if repo != "" {
 		_ = CachedTestFactory.RepoOverride(repo)
 	}
@@ -339,7 +339,7 @@ func StubFactoryWithConfig(repo string) (*cmdutils.Factory, error) {
 		return nil, cmdutils.ConfigError
 	}
 	CachedTestFactory = cmdutils.NewFactory()
-	cmdutils.HTTPClientFactory(CachedTestFactory)
+	CachedTestFactory.HttpClient = cmdutils.HTTPClientFunc
 	if repo != "" {
 		_ = CachedTestFactory.RepoOverride(repo)
 	}
