@@ -30,10 +30,10 @@ func NewCmdList(f *cmdutils.Factory) *cobra.Command {
 		Long:    ``,
 		Aliases: []string{"ls"},
 		Example: heredoc.Doc(`
-			glab label list
-			glab label ls
-			glab label list -R owner/repository
-			glab label list -g mygroup
+			- glab label list
+			- glab label ls
+			- glab label list -R owner/repository
+			- glab label list -g mygroup
 		`),
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
