@@ -8,6 +8,7 @@ import (
 	"strconv"
 	"strings"
 
+	"gitlab.com/gitlab-org/cli/pkg/dbg"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
 	gitlab "gitlab.com/gitlab-org/api/client-go"
@@ -20,8 +21,8 @@ import (
 )
 
 type MRCheckErrOptions struct {
-	// WorkInProgress: check and return err if merge request is a DRAFT
-	WorkInProgress bool
+	// Draft: check and return err if merge request is a DRAFT
+	Draft bool
 	// Closed: check and return err if merge request is closed
 	Closed bool
 	// Merged: check and return err if merge request is already merged
@@ -51,10 +52,17 @@ type mrOptions struct {
 
 // MRCheckErrors checks and return merge request errors specified in MRCheckErrOptions{}
 func MRCheckErrors(mr *gitlab.MergeRequest, err MRCheckErrOptions) error {
-	if mr.WorkInProgress && err.WorkInProgress {
+	if mr.Draft && err.Draft {
 		return fmt.Errorf("this merge request is still a draft. Run `glab mr update %d --ready` to mark it as ready for review.", mr.IID)
 	}
 
+	dbg.Debug("MergeWhenPipelineSucceeds:", strconv.FormatBool(mr.MergeWhenPipelineSucceeds))
+	dbg.Debug("DetailedMergeStatus:", mr.DetailedMergeStatus)
+
+	if mr.DetailedMergeStatus == "ci_must_pass" {
+		return fmt.Errorf("this merge request requires a passing pipeline before merging.")
+	}
+
 	if mr.MergeWhenPipelineSucceeds && err.PipelineStatus && mr.Pipeline != nil {
 		if mr.Pipeline.Status != "success" {
 			return fmt.Errorf("the pipeline for this merge request has failed. The pipeline must succeed before merging.")
@@ -92,7 +100,7 @@ func MRCheckErrors(mr *gitlab.MergeRequest, err MRCheckErrOptions) error {
 	return nil
 }
 
-func DisplayMR(c *iostreams.ColorPalette, mr *gitlab.MergeRequest, isTTY bool) string {
+func DisplayMR(c *iostreams.ColorPalette, mr *gitlab.BasicMergeRequest, isTTY bool) string {
 	mrID := MRState(c, mr)
 	if isTTY {
 		return fmt.Sprintf("%s %s (%s)\n %s\n", mrID, mr.Title, mr.SourceBranch, mr.WebURL)
@@ -101,7 +109,7 @@ func DisplayMR(c *iostreams.ColorPalette, mr *gitlab.MergeRequest, isTTY bool) s
 	}
 }
 
-func MRState(c *iostreams.ColorPalette, m *gitlab.MergeRequest) string {
+func MRState(c *iostreams.ColorPalette, m *gitlab.BasicMergeRequest) string {
 	if m.State == "opened" {
 		return c.Green(fmt.Sprintf("!%d", m.IID))
 	} else if m.State == "merged" {
@@ -111,7 +119,7 @@ func MRState(c *iostreams.ColorPalette, m *gitlab.MergeRequest) string {
 	}
 }
 
-func DisplayAllMRs(streams *iostreams.IOStreams, mrs []*gitlab.MergeRequest) string {
+func DisplayAllMRs(streams *iostreams.IOStreams, mrs []*gitlab.BasicMergeRequest) string {
 	c := streams.Color()
 	table := tableprinter.NewTablePrinter()
 	table.SetIsTTY(streams.IsOutputTTY())
@@ -170,11 +178,11 @@ func MRFromArgsWithOpts(
 	}
 
 	if mrID == 0 {
-		mr, err = getMRForBranch(apiClient, mrOptions{baseRepo, branch, state, f.IO.PromptEnabled()})
+		basicMR, err := getMRForBranch(apiClient, mrOptions{baseRepo, branch, state, f.IO.PromptEnabled()})
 		if err != nil {
 			return nil, nil, err
 		}
-		mrID = mr.IID
+		mrID = basicMR.IID
 	}
 	mr, err = api.GetMR(apiClient, baseRepo.FullName(), mrID, opts)
 	if err != nil {
@@ -227,7 +235,7 @@ func MRsFromArgs(f *cmdutils.Factory, args []string, state string) ([]*gitlab.Me
 	return mrs, baseRepo, nil
 }
 
-var getMRForBranch = func(apiClient *gitlab.Client, mrOpts mrOptions) (*gitlab.MergeRequest, error) {
+var getMRForBranch = func(apiClient *gitlab.Client, mrOpts mrOptions) (*gitlab.BasicMergeRequest, error) {
 	currentBranch := mrOpts.arg // Assume the user is using only 'branch', not 'OWNER:branch'
 	var owner string
 
@@ -279,7 +287,7 @@ var getMRForBranch = func(apiClient *gitlab.Client, mrOpts mrOptions) (*gitlab.M
 	}
 
 	// No 'OWNER:' prompt the user to pick a merge request
-	mrMap := map[string]*gitlab.MergeRequest{}
+	mrMap := map[string]*gitlab.BasicMergeRequest{}
 	var mrNames []string
 	for i := range mrs {
 		t := fmt.Sprintf("!%d (%s) by @%s", mrs[i].IID, currentBranch, mrs[i].Author.Username)
@@ -368,6 +376,7 @@ func PrintMRApprovalState(ios *iostreams.IOStreams, mrApprovals *gitlab.MergeReq
 			approvedBy[by.Username] = by
 		}
 
+		table.AddRow("Name", "Username", "Approved")
 		for _, eligibleApprover := range eligibleApprovers {
 			approved := "-"
 			source := ""
