@@ -32,6 +32,22 @@ import (
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
 
+type noteOptions int
+
+const (
+	noteOptMyOwn noteOptions = iota
+	noteOptCommitLog
+	noteOptGitTagMessage
+	noteOptLeaveBlank
+)
+
+var noteOptionsNames = map[noteOptions]string{
+	noteOptMyOwn:         "Write my own.",
+	noteOptCommitLog:     "Write using the commit log as a template.",
+	noteOptGitTagMessage: "Write using the Git tag message as the template.",
+	noteOptLeaveBlank:    "Leave blank.",
+}
+
 type CreateOpts struct {
 	Name                        string
 	Ref                         string
@@ -85,29 +101,29 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 		`, "`"),
 		Args: cmdutils.MinimumArgs(1, "no tag name provided."),
 		Example: heredoc.Docf(`
-			# Create a release interactively
-			$ glab release create v1.0.1
+			Create a release interactively
+			- glab release create v1.0.1
 
-			# Create a release non-interactively by specifying a note
-			$ glab release create v1.0.1 --notes "bugfix release"
+			Create a release non-interactively by specifying a note
+			- glab release create v1.0.1 --notes "bugfix release"
 
-			# Use release notes from a file
-			$ glab release create v1.0.1 -F changelog.md
+			Use release notes from a file
+			- glab release create v1.0.1 -F changelog.md
 
-			# Upload a release asset with a display name (type will default to 'other')
-			$ glab release create v1.0.1 '/path/to/asset.zip#My display label'
+			Upload a release asset with a display name (type will default to 'other')
+			- glab release create v1.0.1 '/path/to/asset.zip#My display label'
 
-			# Upload a release asset with a display name and type
-			$ glab release create v1.0.1 '/path/to/asset.png#My display label#image'
+			Upload a release asset with a display name and type
+			- glab release create v1.0.1 '/path/to/asset.png#My display label#image'
 
-			# Upload all assets in a specified folder (types default to 'other')
-			$ glab release create v1.0.1 ./dist/*
+			Upload all assets in a specified folder (types default to 'other')
+			- glab release create v1.0.1 ./dist/*
 
-			# Upload all tarballs in a specified folder (types default to 'other')
-			$ glab release create v1.0.1 ./dist/*.tar.gz
+			Upload all tarballs in a specified folder (types default to 'other')
+			- glab release create v1.0.1 ./dist/*.tar.gz
 
-			# Create a release with assets specified as JSON object
-			$ glab release create v1.0.1 --assets-links='
+			Create a release with assets specified as JSON object
+			- glab release create v1.0.1 --assets-links='
 			  [
 			    {
 			      "name": "Asset1",
@@ -134,8 +150,8 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			#   for components that bundle together multiple related files. For example,
 			#   %[1]stemplates/secret-detection/template.yml%[1]s.
 
-			$ glab release create v1.0.1 --publish-to-catalog
-`, "`"),
+			- glab release create v1.0.1 --publish-to-catalog
+		`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
 			opts.RepoOverride, _ = cmd.Flags().GetString("repo")
@@ -316,14 +332,14 @@ func createRun(opts *CreateOpts) error {
 			}
 		}
 
-		editorOptions := []string{"Write my own."}
+		editorOptions := []string{noteOptionsNames[noteOptMyOwn]}
 		if generatedChangelog != "" {
-			editorOptions = append(editorOptions, "Write using the commit log as a template.")
+			editorOptions = append(editorOptions, noteOptionsNames[noteOptCommitLog])
 		}
 		if tagDescription != "" {
-			editorOptions = append(editorOptions, "Write using the Git tag message as the template.")
+			editorOptions = append(editorOptions, noteOptionsNames[noteOptGitTagMessage])
 		}
-		editorOptions = append(editorOptions, "Leave blank.")
+		editorOptions = append(editorOptions, noteOptionsNames[noteOptLeaveBlank])
 
 		qs := []*survey.Question{
 			{
@@ -350,15 +366,15 @@ func createRun(opts *CreateOpts) error {
 		var editorContents string
 
 		switch opts.ReleaseNotesAction {
-		case "Write my own.":
+		case noteOptionsNames[noteOptMyOwn]:
 			openEditor = true
-		case "Write using commit log as template.":
+		case noteOptionsNames[noteOptCommitLog]:
 			openEditor = true
 			editorContents = generatedChangelog
-		case "Write using git tag message as template.":
+		case noteOptionsNames[noteOptGitTagMessage]:
 			openEditor = true
 			editorContents = tagDescription
-		case "Leave blank.":
+		case noteOptionsNames[noteOptLeaveBlank]:
 			openEditor = false
 		default:
 			return fmt.Errorf("invalid action: %v", opts.ReleaseNotesAction)
