@@ -19,7 +19,7 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 		Use:   "create [flags]",
 		Short: `Schedule a new pipeline.`,
 		Example: heredoc.Doc(`
-			glab schedule create --cron "0 * * * *" --description "Describe your pipeline here" --ref "main" --variable "foo:bar" --variable "baz:baz"
+			- glab schedule create --cron "0 * * * *" --description "Describe your pipeline here" --ref "main" --variable "foo:bar" --variable "baz:baz"
 		`),
 		Long: ``,
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -62,7 +62,7 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 				}
 				variable.Key = &split[0]
 				variable.Value = &split[1]
-				err = api.CreateScheduleVariable(apiClient, repo.FullName(), schedule, variable)
+				err = api.CreateScheduleVariable(apiClient, repo.FullName(), schedule.ID, variable)
 				if err != nil {
 					return err
 				}
