@@ -22,10 +22,10 @@ func NewCmdDelete(f *cmdutils.Factory) *cobra.Command {
 		IO: f.IO,
 	}
 	scheduleDeleteCmd := &cobra.Command{
-		Use:   "delete [flags]",
-		Short: `Delete schedule with the specified ID.`,
+		Use:   "delete <id> [flags]",
+		Short: `Delete the schedule with the specified ID.`,
 		Example: heredoc.Doc(`
-			glab schedule delete 10
+			- glab schedule delete 10
 		`),
 		Long: ``,
 		Args: cobra.ExactArgs(1),
