@@ -10,7 +10,7 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 func NewCmdList(f *cmdutils.Factory) *cobra.Command {
@@ -18,7 +18,7 @@ func NewCmdList(f *cmdutils.Factory) *cobra.Command {
 		Use:   "list [flags]",
 		Short: `Get the list of schedules.`,
 		Example: heredoc.Doc(`
-			glab schedule list
+			- glab schedule list
 		`),
 		Long: ``,
 		Args: cobra.ExactArgs(0),
