@@ -52,20 +52,20 @@ func NewCmdRevoke(f *cmdutils.Factory, runE func(opts *RevokeOptions) error) *co
 		`),
 
 		Example: heredoc.Doc(`
-			# Revoke a project access token of current project
-			glab token revoke my-project-token
+			Revoke a project access token of current project
+			- glab token revoke my-project-token
 
-			# Revoke a project access token of a specific project
-			glab token revoke --repo user/my-repo my-project-token
+			Revoke a project access token of a specific project
+			- glab token revoke --repo user/my-repo my-project-token
 
-			# Revoke a group access token
-			glab token revoke --group group/sub-group my-group-token
+			Revoke a group access token
+			- glab token revoke --group group/sub-group my-group-token
 
-			# Revoke my personal access token
-			glab token revoke --user @me my-personal-token
+			Revoke my personal access token
+			- glab token revoke --user @me my-personal-token
 
-			# Revoke a personal access token of another user (administrator only)
-			glab token revoke --user johndoe johns-personal-token
+			Revoke a personal access token of another user (administrator only)
+			- glab token revoke --user johndoe johns-personal-token
 
 		`),
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
